@@ -18,10 +18,12 @@
 
 package org.apache.seatunnel.api.table.catalog.exception;
 
+import org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode;
 import org.apache.seatunnel.api.table.catalog.TablePath;
+import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
 
 /** Exception for trying to operate on a table that doesn't exist. */
-public class TableNotExistException extends Exception {
+public class TableNotExistException extends SeaTunnelRuntimeException {
 
     private static final String MSG = "Table %s does not exist in Catalog %s.";
 
@@ -30,6 +32,6 @@ public class TableNotExistException extends Exception {
     }
 
     public TableNotExistException(String catalogName, TablePath tablePath, Throwable cause) {
-        super(String.format(MSG, tablePath.getFullName(), catalogName), cause);
+        super(SeaTunnelAPIErrorCode.TABLE_NOT_EXISTED, String.format(MSG, tablePath.getFullName(), catalogName), cause);
     }
 }
