@@ -18,5 +18,5 @@
 package org.apache.seatunnel.common.constants;
 
 public enum JobMode {
-    BATCH, STREAMING, STRUCTURED_STREAMING
+    BATCH, STREAMING
 }
