@@ -17,9 +17,9 @@
 
 package org.apache.seatunnel.common.config;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.io.File;
 
@@ -31,7 +31,7 @@ public class CommonTest {
 
     @Test
     public void appLibDir() {
-        assertEquals(Common.appRootDir().toString() + File.separator + "lib", Common.appLibDir().toString());
+        assertEquals(Common.appRootDir().toString() + File.separator + "starter", Common.appStarterDir().toString());
     }
 
     @Test
